{ config, lib, pkgs, ... }:

let
  mkHost = (import ../modules { lib = lib; pkgs = pkgs; }).mkHost;
in mkHost config {
  userName = "alexander";
  hostName = "mashu";
  overlays = [ "nur" "unstable" "simple" "custom" ];
  hardwareImports = [
    "intel"
    "wifi"
    "mobile"
    "surface-pro6"
  ];
  wireless = true;
  wifiInterface = "wlp1s0";
  programImports = [
    "zsh" "git" "mpv" "tmux" "firefox" "gnome-terminal" "gnome" "i18n"
    "distributed-build/offload.nix"
  ];
  fileSystems = {
    "/" = {
      device = "/dev/disk/by-label/root";
      fsType = "btrfs";
    };
    "/boot" = {
      device = "/dev/disk/by-label/boot";
      fsType = "vfat";
    };
  };
  swapDevices = [
    {
      device = "/dev/disk/by-label/swap";
    }
  ];
  extraOptions = old: {
    networking.wireless.enable = true;
    hardware.video.hidpi.enable = true;
    boot = {
      extraModprobeConfig = ''
        options kvm_amd nested=1
        options vfio-pci ids=1002:67df,1002:aaf0
      '';
      initrd = {
        availableKernelModules = [ "xhci_pci" "nvme" "usbhid" ];
        kernelModules = [ "kvm-intel" ];
      };
    };
  };
}
